pyobject_to_latency_model_any

Function pyobject_to_latency_model_any 

pub fn pyobject_to_latency_model_any(
    obj: &Bound<'_, PyAny>,
) -> PyResult<LatencyModelAny>
Extracts a Python latency model object into a Rust LatencyModelAny.

Errors

Returns an error if obj is not a supported latency model binding.