pub fn pyobject_to_latency_model_any(
obj: &Bound<'_, PyAny>,
) -> PyResult<LatencyModelAny>Expand description
Extracts a Python latency model object into a Rust LatencyModelAny.
Errors
Returns an error if obj is not a supported latency model binding.